@@ -3,6 +3,7 @@ package HPC::Runner::Command::execute_job::Base;
 use Moose::Role;
 
 with 'HPC::Runner::Command::execute_job::Utils::Log';
+use Sys::Hostname;
 
 =head3 job_scheduler_id
 
@@ -28,6 +29,14 @@ q{This defaults to your current Job Scheduler ID. Ignore this if running on a si
     clearer   => 'clear_job_scheduler_id',
 );
 
+has 'hostname' => (
+  is => 'rw',
+  isa => 'Str|Undef',
+  default => sub {
+    return hostname;
+  },
+);
+
 has 'wait' => (
     is      => 'rw',
     isa     => 'Bool',
